Skip to contents

This function generates a lookup table that indicates the land-use types where species are predicted to be present, based on model predictions and specified thresholds.

Usage

Generate_Lookup(Model, Thresholds)

Arguments

Model

A data frame containing model predictions, with columns for species, Landuse, and Pred.

Thresholds

A data frame containing the thresholds for presence predictions, with columns for species, Thres_99, Thres_95, and Thres_90.

Value

A data frame that indicates the land-use types where species are predicted to be present. The data frame contains columns for species, Landuse, and Pres.