Skip to contents

This function takes a CSV file path, reads the data, and generates a phylogenetic tree using the V.PhyloMaker package.

Usage

generate_tree(DF)

Arguments

DF

A data.frame. The data.frame must contain columns named species, genus, and family.

Value

A phylogenetic tree object generated by the V.PhyloMaker::phylo.maker function.