This function samples land-use data either from species presence locations or from background locations within a specified geographic area.
Arguments
- DF
A data frame containing species presence or background data, with columns for
species,decimalLongitude, anddecimalLatitude.- file
A string representing the path to a raster file that contains land-use data.
- type
A string specifying whether to sample land-use data from species presences (
"pres") or from background locations ("bg"). Defaults to"pres".