This function generates thresholds for species distribution predictions based on modeled land-use preferences. Thresholds are calculated for the 99th, 95th, and 90th percentiles of the predicted values.
Usage
create_thresholds(Model, reference, file)
Arguments
- Model
A data frame containing model predictions, with columns for species, Landuse, and Pred.
- reference
A data frame containing reference species presence data for threshold calibration.
- file
A string representing the path to a raster file that contains land-use data.
Value
A data frame with the calculated thresholds. The data frame contains columns for species, Thres_99, Thres_95, and Thres_90.