Export Final Species Presences to CSV Files
Source:R/export_final_presences.R
export_final_presences.RdThis function exports the final filtered species presences to CSV files. The data is grouped by land-use type, and each species is saved in a separate CSV file within a folder corresponding to its land-use type.