This function takes a data.table of rarity results and a path to a raster template.
It generates a SpatRaster object using the terra package, populates it with the rarity values,
and writes the result out as a Cloud-Optimized GeoTIFF.
Arguments
- Results
A data.table containing rarity results. This data.table must contain at least the columns
cellandIrr, wherecellrefers to the cell index in the raster andIrrrefers to the rarity value.- path
A character string specifying the file path to a raster template. This raster is used as a template for the output raster.