This function takes a CSV file path, reads the data, and generates a phylogenetic tree using the V.PhyloMaker package.
Value
A phylogenetic tree object generated by the V.PhyloMaker::phylo.maker function.
This function takes a CSV file path, reads the data, and generates a phylogenetic tree using the V.PhyloMaker package.
A phylogenetic tree object generated by the V.PhyloMaker::phylo.maker function.